@@ -2,39 +2,61 @@ import os
 
 from pyotrs import Client
 from pyotrs.lib import DynamicField
-from pyotrs.lib import APIError, HTTPError, ResponseParseError, SessionNotCreated, ArgumentMissingError
+from pyotrs.lib import (
+    APIError,
+    HTTPError,
+    ResponseParseError,
+    SessionNotCreated,
+    ArgumentMissingError,
+)
 
 from otrs_somconnexio.responses.ticket_creation import OTRSCreationTicketResponse
 from otrs_somconnexio.otrs_models.process_ticket.internet import InternetProcessTicket
 from otrs_somconnexio.otrs_models.process_ticket.mobile import MobileProcessTicket
 from otrs_somconnexio.otrs_models.coverage_ticket import CoverageTicket
 from otrs_somconnexio.otrs_models.service import Service
-from otrs_somconnexio.exceptions import TicketNotCreated, ErrorCreatingSession, TicketNotFoundError
+from otrs_somconnexio.exceptions import (
+    TicketNotCreated,
+    ErrorCreatingSession,
+    TicketNotFoundError,
+)
 
 
-class OTRSClient():
+class OTRSClient:
     TICKET_CONNECTOR_CONFIG = {
-        'Name': 'GenericTicketConnectorREST',
-        'Config': {
-            'SessionCreate': {'RequestMethod': 'POST',
-                              'Route': '/Session',
-                              'Result': 'SessionID'},
-            'TicketCreate': {'RequestMethod': 'POST',
-                             'Route': '/Ticket',
-                             'Result': 'TicketID'},
-            'TicketGet': {'RequestMethod': 'GET',
-                          'Route': '/Ticket/:TicketID',
-                          'Result': 'Ticket'},
-            'TicketGetList': {'RequestMethod': 'GET',
-                              'Route': '/TicketList',
-                              'Result': 'Ticket'},
-            'TicketSearch': {'RequestMethod': 'POST',
-                             'Route': '/TicketSearch',
-                             'Result': 'TicketID'},
-            'TicketUpdate': {'RequestMethod': 'PATCH',
-                             'Route': '/Ticket/:TicketID',
-                             'Result': 'TicketID'},
-        }
+        "Name": "GenericTicketConnectorREST",
+        "Config": {
+            "SessionCreate": {
+                "RequestMethod": "POST",
+                "Route": "/Session",
+                "Result": "SessionID",
+            },
+            "TicketCreate": {
+                "RequestMethod": "POST",
+                "Route": "/Ticket",
+                "Result": "TicketID",
+            },
+            "TicketGet": {
+                "RequestMethod": "GET",
+                "Route": "/Ticket/:TicketID",
+                "Result": "Ticket",
+            },
+            "TicketGetList": {
+                "RequestMethod": "GET",
+                "Route": "/TicketList",
+                "Result": "Ticket",
+            },
+            "TicketSearch": {
+                "RequestMethod": "POST",
+                "Route": "/TicketSearch",
+                "Result": "TicketID",
+            },
+            "TicketUpdate": {
+                "RequestMethod": "PATCH",
+                "Route": "/Ticket/:TicketID",
+                "Result": "TicketID",
+            },
+        },
     }
 
     def __init__(self):
@@ -42,18 +64,18 @@ class OTRSClient():
 
     @staticmethod
     def _password():
-        return os.environ['OTRS_PASSW']
+        return os.environ["OTRS_PASSW"]
 
     @staticmethod
     def _user():
-        return os.environ['OTRS_USER']
+        return os.environ["OTRS_USER"]
 
     @staticmethod
     def _url():
-        return os.environ['OTRS_URL']
+        return os.environ["OTRS_URL"]
 
     def _create_client_with_session(self):
-        """ Create a OTRS Client with session open to play calls.
+        """Create a OTRS Client with session open to play calls.
 
         This method call to the OTRS API to create a session to play another requests with authentication done.
         Raise User errors to show the problem with the request if it is fault.
@@ -65,7 +87,8 @@ class OTRSClient():
                 baseurl=self._url(),
                 username=self._user(),
                 password=self._password(),
-                webservice_config_ticket=self.TICKET_CONNECTOR_CONFIG
+                webservice_config_ticket=self.TICKET_CONNECTOR_CONFIG,
+                use_legacy_sessions=True,
             )
             client.session_create()
         except (HTTPError, APIError, ResponseParseError) as error:
@@ -73,7 +96,7 @@ class OTRSClient():
         return client
 
     def create_otrs_process_ticket(self, ticket, article, dynamic_fields):
-        """ Create a OTRS Process Ticket to manage the provisioning.
+        """Create a OTRS Process Ticket to manage the provisioning.
 
         This method call to the OTRS API to create a ticket with all the information of the econtract.
         If the Ticket is created, return the response to save the ID and the number in the EticomContract
@@ -84,15 +107,20 @@ class OTRSClient():
         """
         try:
             client_response = self.client.ticket_create(
-                ticket=ticket,
-                article=article,
-                dynamic_fields=dynamic_fields)
-        except (HTTPError, APIError, ResponseParseError, SessionNotCreated, ArgumentMissingError) as error:
+                ticket=ticket, article=article, dynamic_fields=dynamic_fields
+            )
+        except (
+            HTTPError,
+            APIError,
+            ResponseParseError,
+            SessionNotCreated,
+            ArgumentMissingError,
+        ) as error:
             raise TicketNotCreated(error.message, dynamic_fields)
         return OTRSCreationTicketResponse(client_response)
 
     def get_otrs_process_ticket(self, ticket_id):
-        """ Search a OTRS Process Ticket by ID.
+        """Search a OTRS Process Ticket by ID.
 
         This method call to the OTRS API to search a ticket with all the information of the provisioning process.
         If the Ticket is founded, return the Ticket object.
@@ -119,13 +147,15 @@ class OTRSClient():
     def search_coverage_tickets_by_email(self, email):
         df_process_id = {
             "name": "ProcessManagementProcessID",
-            "value": "Process-be8cf222949132c9fae1bb74615a5ae4"
+            "value": "Process-be8cf222949132c9fae1bb74615a5ae4",
         }
 
         tickets = self.search_tickets(
             dynamic_fields=[
-                DynamicField(df_process_id["name"], search_patterns=[df_process_id["value"]]),
-                DynamicField("correuElectronic", search_patterns=[email])
+                DynamicField(
+                    df_process_id["name"], search_patterns=[df_process_id["value"]]
+                ),
+                DynamicField("correuElectronic", search_patterns=[email]),
             ]
         )
         return [CoverageTicket(t) for t in tickets]
@@ -141,27 +171,27 @@ class OTRSClient():
         return ticket
 
     def update_ticket(self, ticket_id, article, dynamic_fields=[]):
-        self.client.ticket_update(
-            ticket_id,
-            article,
-            dynamic_fields=dynamic_fields
-        )
+        self.client.ticket_update(ticket_id, article, dynamic_fields=dynamic_fields)
 
-    def update_ticket_if_not_set(self, ticket_id, article, dynamic_fields=[]):
-        ticket = self.client.ticket_get_by_id(ticket_id, dynamic_fields=True)
-        if all(not ticket.dynamic_field_get(df.name).value for df in dynamic_fields):
-            self.update_ticket(ticket_id, article, dynamic_fields)
-
-    def link_tickets(self, src_ticket_id, dst_ticket_id,
-                     link_type="Normal"):
+    def link_tickets(self, src_ticket_id, dst_ticket_id, link_type="Normal"):
         """
         Sets a LINK between to OTRS tickets to interconnect them.
         """
-        self.client.link_add(
-            src_ticket_id,
-            dst_ticket_id,
-            link_type=link_type
+        self.client.link_add(src_ticket_id, dst_ticket_id, link_type=link_type)
+
+    def get_linked_tickets(self, src_ticket_id, link_type="Normal"):
+        """
+        Gets tickets linked with the one which ID is passed as parameter (src_ticket_id).
+        """
+        linked_tickets_response = self.client.link_list(
+            src_object_id=src_ticket_id, link_type=link_type
         )
+        if isinstance(linked_tickets_response, list):
+            ticket_ids = [ticket["Key"] for ticket in linked_tickets_response]
+        else:
+            ticket_ids = [linked_tickets_response["Key"]]
+
+        return [self.get_otrs_process_ticket(ticket_id) for ticket_id in ticket_ids]
 
     def _process_ticket_response(self, ticket):
         service = Service(ticket)
