@@ -6,12 +6,13 @@ class OTRSClientException(Exception):
 
 class ErrorCreatingSession(OTRSClientException):
     def __init__(self, error_msg):
-        message = "Error creating the session with the next error message: {}".format(error_msg)
+        message = "Error creating the session with the next error message: {}".format(
+            error_msg
+        )
         super(OTRSClientException, self).__init__(message)
 
 
 class TicketNotCreated(OTRSClientException):
-
     def _DF_to_string(self, df_list):
         if not df_list or len(df_list) == 0:
             return ""
@@ -31,8 +32,10 @@ class TicketNotCreated(OTRSClientException):
 
 
 class TicketNotFoundError(OTRSClientException):
-    def __init__(self, ticket_id, error_msg=''):
-        message = "Error searching the ticket with ID {} with the next error message: {}".format(ticket_id, error_msg)
+    def __init__(self, ticket_id, error_msg=""):
+        message = "Error searching the ticket with ID {} with the next error message: {}".format(
+            ticket_id, error_msg
+        )
         super(OTRSClientException, self).__init__(message)
 
 
@@ -44,5 +47,15 @@ class UserManagementResponseEmpty(OTRSClientException):
 
 class ServiceTypeNotAllowedError(OTRSClientException):
     def __init__(self, id, service_type):
-        message = "Contract {} with service type not allowed: {}".format(id, service_type)
+        message = "Contract {} with service type not allowed: {}".format(
+            id, service_type
+        )
+        super(OTRSClientException, self).__init__(message)
+
+
+class TicketNotReadyToBeUpdatedWithSIMReceivedData(OTRSClientException):
+    def __init__(self, ticket_number):
+        message = "Ticket {} not ready to be updated with SIM received data".format(
+            ticket_number
+        )
         super(OTRSClientException, self).__init__(message)
