@@ -6,12 +6,15 @@ class AbstractArticle:
 
     subject = ""
     body = ""
+    # Parameter to mark notes field red and available only for personnel
+    isVisibleForCustomer = "1"
 
     def call(self):
         article_params = {
             "Subject": self.subject,
             "Body": self.body,
             "ContentType": "text/plain; charset=utf8",
+            "IsVisibleForCustomer": self.isVisibleForCustomer,
         }
 
         return Article(article_params)
