@@ -3,6 +3,7 @@ class VdfFibreCoverage:
         ("fibraCoaxial", "Fibra (coaxial)"),
         ("fibraFTTH", "Fibra (FTTH)"),
         ("NEBAFTTH", "Fibra (NEBA)"),
+        ("asociatel", "Asociatel VDF"),
         ("NoFibraVdf", "No fibra"),
-        ("NoRevisat", "No revisat")
+        ("NoRevisat", "No revisat"),
     ]
