@@ -6,10 +6,26 @@ class CoverageArticle(AbstractArticle):
     """
     This entity gets created from a CoverageTicket.
     """
+
     dynamic_fields_names = (
-        "tipusVia", "nomVia", "numero", "bloc", "portal", "pis", "escala", "porta",
-        "poblacioServei", "provinciaServei", "codiProvinciaServei", "CPservei", "altresCobertura",
-        "coberturaADSL", "coberturaFibraMM", "coberturaFibraVdf", "coberturaFibraOrange", "IDhogar"
+        "tipusVia",
+        "nomVia",
+        "numero",
+        "bloc",
+        "portal",
+        "pis",
+        "escala",
+        "porta",
+        "poblacioServei",
+        "provinciaServei",
+        "codiProvinciaServei",
+        "CPservei",
+        "altresCobertura",
+        "coberturaADSL",
+        "coberturaFibraMM",
+        "coberturaFibraVdf",
+        "coberturaFibraOrange",
+        "IDhogar",
     )
     subject = "Sol·licitud cobertura"
 
@@ -22,5 +38,5 @@ class CoverageArticle(AbstractArticle):
         for df_name in self.dynamic_fields_names:
             df_value = getattr(self.ticket, df_name)
             if df_value:
-                body = u"{}{}: {}\n".format(body, df_name, df_value)
+                body = "{}{}: {}\n".format(body, df_name, df_value)
         return body
