@@ -1,6 +1,18 @@
 class CustomerData:
-    def __init__(self, id, vat_number, phone, name, first_name, street,
-                 city, zip, subdivision, has_active_contracts, language):
+    def __init__(
+        self,
+        id,
+        vat_number,
+        phone,
+        name,
+        first_name,
+        street,
+        city,
+        zip,
+        subdivision,
+        has_active_contracts,
+        language,
+    ):
         self.id = id
         self.vat_number = vat_number
         self.phone = phone
