@@ -7,19 +7,13 @@ class CustomerUser:
         self.client = client(self.id)
 
     def change_language(self, lang):
-        self.client.set_preference(
-            'UserLanguage',
-            lang
-        )
+        self.client.set_preference("UserLanguage", lang)
 
     def set_mm_account_id(self, mm_account_id):
         """
         Set "MMAccountId" parameter in the OTRS preferences from this CustomerUser
         """
-        self.client.set_preference(
-            'MMAccountId',
-            mm_account_id
-        )
+        self.client.set_preference("MMAccountId", mm_account_id)
 
     def get_mm_account_id(self):
         """
@@ -28,7 +22,7 @@ class CustomerUser:
         """
         preferences = self.client.get_preferences()
 
-        return preferences.get('MMAccountId')
+        return preferences.get("MMAccountId")
 
     def get_data(self):
         return self.client.get_data()
