@@ -1,13 +1,31 @@
 class MobileData:
-    service_type = 'mobile'
+    service_type = "mobile"
 
     def __init__(
-        self, order_id, phone_number, iban, email, sc_icc, icc,
-        has_sim, type, previous_owner_vat, previous_owner_name,
-        previous_owner_surname, previous_provider, product, delivery_street,
-        delivery_city, delivery_zip_code, delivery_state, technology,
-        sim_delivery_tracking_code, notes="",
-        is_grouped_with_fiber=False, fiber_linked="",
+        self,
+        order_id,
+        phone_number,
+        iban,
+        email,
+        sc_icc,
+        icc,
+        has_sim,
+        type,
+        previous_owner_vat,
+        previous_owner_name,
+        previous_owner_surname,
+        previous_provider,
+        product,
+        delivery_street,
+        delivery_city,
+        delivery_zip_code,
+        delivery_state,
+        technology,
+        sim_delivery_tracking_code,
+        notes="",
+        is_grouped_with_fiber=False,
+        fiber_linked="",
+        shared_bond_id="",
     ):
         self.order_id = order_id
         self.phone_number = phone_number
@@ -31,3 +49,4 @@ class MobileData:
         self.notes = notes
         self.is_grouped_with_fiber = is_grouped_with_fiber
         self.fiber_linked = fiber_linked
+        self.shared_bond_id = shared_bond_id
