@@ -4,7 +4,7 @@ from otrs_somconnexio.services.get_ticket_title import GetTicketTitle
 
 
 class ProvisionArticle(AbstractArticle):
-    def __init__(self, technology, order_id, service_type, notes=''):
+    def __init__(self, technology, order_id, service_type, notes=""):
         subject = GetTicketTitle(technology, order_id, service_type).build()
         self.subject = subject
         if notes:
