@@ -14,7 +14,12 @@ class SearchTicketsService:
         configuration_class: Any ticket configuration class from 'otrs-models/configurations'
         folder in this package
         """
-        self.configuration = configuration_class
+        self.configurations = configuration_class
+
+        if not isinstance(configuration_class, list):
+            self.configurations = [configuration_class]
+        else:
+            self.configurations = configuration_class
 
     def search(self, customer_code, state_list=["new"], df_dct={}):
         """
@@ -26,10 +31,14 @@ class SearchTicketsService:
 
         otrs_client = OTRSClient()
 
-        process_id_df = DynamicField("ProcessManagementProcessID",
-                                     self.configuration.process_id)
-        activity_id_df = DynamicField("ProcessManagementActivityID",
-                                      self.configuration.activity_id)
+        process_id_df = DynamicField(
+            "ProcessManagementProcessID",
+            search_patterns=list(map(lambda c: c.process_id, self.configurations)),
+        )
+        activity_id_df = DynamicField(
+            "ProcessManagementActivityID",
+            search_patterns=list(map(lambda c: c.activity_id, self.configurations)),
+        )
         df_list = [process_id_df, activity_id_df]
 
         for key, value in df_dct.items():
@@ -37,7 +46,7 @@ class SearchTicketsService:
 
         search_args = {
             "dynamic_fields": df_list,
-            "Queues": [self.configuration.queue],
+            "Queues": list(map(lambda c: c.queue, self.configurations)),
             "CustomerID": customer_code,
             "States": state_list,
         }
