@@ -13,10 +13,9 @@ class SetFiberContractCodeMobileTicket(UpdateTicketDF):
         self.fiber_contract_code = fiber_contract_code
         super().__init__(ticket_number)
 
-    def _prepare_dynamic_fields(self, ticket):
+    def _prepare_dynamic_fields(self):
         return [
             DynamicField(
-                name='OdooContractRefRelacionat',
-                value=self.fiber_contract_code
+                name="OdooContractRefRelacionat", value=self.fiber_contract_code
             )
         ]
