@@ -19,9 +19,8 @@ class UpdateTicketWithProviderInfo:
         pyOTRS_article = self.article.call()
 
         otrs_client.update_ticket(
-            self.ticket_id,
-            pyOTRS_article,
-            dynamic_fields=dynamic_fields)
+            self.ticket_id, pyOTRS_article, dynamic_fields=dynamic_fields
+        )
 
     def _df_list_from_dct(self, df_dct):
 
