@@ -2,13 +2,12 @@ import logging
 
 from otrs_somconnexio.exceptions import UserManagementResponseEmpty
 
-logger = logging.getLogger('otrs_somconnexio')
+logger = logging.getLogger("otrs_somconnexio")
 
 
 class UserManagementResponse:
-
     def __init__(self, raw_response, user_id, call):
-        self.raw_data = raw_response.json()['Result']
+        self.raw_data = raw_response.json()["Result"]
         if self.raw_data == []:
             raise UserManagementResponseEmpty(user_id, call)
 
