@@ -18,46 +18,50 @@ def dynamic_fields_to_dct(dynamic_fields):
 
 class ADSLDynamicFieldsTestCase(unittest.TestCase):
     def setUp(self):
-        self.customer_data = Mock(spec=[
-            'first_name',
-            'name',
-            'vat_number',
-            'phone',
-            'has_active_contracts',
-            'language'
-        ])
-        self.service_data = Mock(spec=[
-            'order_id',
-            'iban',
-            'email',
-            'phone_number',
-            'landline_phone_number',
-            'service_address',
-            'service_city',
-            'service_zip',
-            'service_subdivision',
-            'service_subdivision_code',
-            'shipment_address',
-            'shipment_city',
-            'shipment_zip',
-            'shipment_subdivision',
-            'previous_service',
-            'previous_provider',
-            'previous_owner_vat',
-            'previous_owner_name',
-            'previous_owner_surname',
-            'previous_contract_address',
-            'previous_contract_phone',
-            'notes',
-            'adsl_coverage',
-            'mm_fiber_coverage',
-            'vdf_fiber_coverage',
-            'orange_fiber_coverage',
-            'type',
-            'product',
-            'previous_internal_provider',
-            'technology'
-        ])
+        self.customer_data = Mock(
+            spec=[
+                "first_name",
+                "name",
+                "vat_number",
+                "phone",
+                "has_active_contracts",
+                "language",
+            ]
+        )
+        self.service_data = Mock(
+            spec=[
+                "order_id",
+                "iban",
+                "email",
+                "phone_number",
+                "landline_phone_number",
+                "service_address",
+                "service_city",
+                "service_zip",
+                "service_subdivision",
+                "service_subdivision_code",
+                "shipment_address",
+                "shipment_city",
+                "shipment_zip",
+                "shipment_subdivision",
+                "previous_service",
+                "previous_provider",
+                "previous_owner_vat",
+                "previous_owner_name",
+                "previous_owner_surname",
+                "previous_contract_address",
+                "previous_contract_phone",
+                "notes",
+                "adsl_coverage",
+                "mm_fiber_coverage",
+                "vdf_fiber_coverage",
+                "orange_fiber_coverage",
+                "type",
+                "product",
+                "previous_internal_provider",
+                "technology",
+            ]
+        )
 
         self.adsl_otrs_process_id = "ADSLProcessID"
         self.adsl_otrs_activity_id = "ADSLActivityID"
@@ -67,29 +71,33 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["ProcessManagementProcessID"], "ADSLProcessID")
+        self.assertEqual(
+            dynamic_fields_dct["ProcessManagementProcessID"], "ADSLProcessID"
+        )
 
     def test_activity_id_field(self):
         dynamic_fields = ADSLDynamicFields(
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["ProcessManagementActivityID"], "ADSLActivityID")
+        self.assertEqual(
+            dynamic_fields_dct["ProcessManagementActivityID"], "ADSLActivityID"
+        )
 
     def test_contract_id_field(self):
         dynamic_fields = ADSLDynamicFields(
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -102,7 +110,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -115,7 +123,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -128,7 +136,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -141,7 +149,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -154,7 +162,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -167,7 +175,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -180,7 +188,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -193,7 +201,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -206,7 +214,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -219,7 +227,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -232,7 +240,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -246,7 +254,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -259,7 +267,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -272,7 +280,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -285,7 +293,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -298,7 +306,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -311,7 +319,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -324,7 +332,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -337,7 +345,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -350,7 +358,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -363,7 +371,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -376,7 +384,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -389,7 +397,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -402,7 +410,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -415,7 +423,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -428,7 +436,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -441,7 +449,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -454,7 +462,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -468,7 +476,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -481,7 +489,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -494,7 +502,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -509,7 +517,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -525,7 +533,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -533,13 +541,13 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertNotIn("nomCognomSociAntic", dynamic_fields_dct.keys())
 
     def test_previous_provider_does_not_exist_when_location_change(self):
-        self.service_data.type = 'location_change'
+        self.service_data.type = "location_change"
 
         dynamic_fields = ADSLDynamicFields(
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -552,7 +560,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
+            self.adsl_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
