@@ -8,16 +8,16 @@ from otrs_somconnexio.otrs_models.coverage_ticket import CoverageTicket
 
 
 class CoverageArticleTestCase(unittest.TestCase):
-
     def setUp(self):
-        ticket = Mock(spec=['response'])
-        ticket.response = Mock(spec=['dynamic_field_get'])
-        df_tipusVia = Mock(spec=['value'])
-        df_tipusVia.value = 'street'
+        ticket = Mock(spec=["response"])
+        ticket.response = Mock(spec=["dynamic_field_get"])
+        df_tipusVia = Mock(spec=["value"])
+        df_tipusVia.value = "street"
 
         def dynamic_field_side_effect(field_name):
-            if field_name == 'tipusVia':
+            if field_name == "tipusVia":
                 return df_tipusVia
+
         ticket.response.dynamic_field_get.side_effect = dynamic_field_side_effect
         self.coverage_ticket = CoverageTicket(ticket)
 
@@ -39,4 +39,6 @@ class CoverageArticleTestCase(unittest.TestCase):
     def test_call_ContentType(self):
         coverage_article = CoverageArticle(self.coverage_ticket).call()
 
-        self.assertEqual(coverage_article.field_get("ContentType"), "text/plain; charset=utf8")
+        self.assertEqual(
+            coverage_article.field_get("ContentType"), "text/plain; charset=utf8"
+        )
