@@ -5,7 +5,6 @@ from otrs_somconnexio.otrs_models.coverage_ticket import CoverageTicket
 
 
 class CoverageTicketTestCase(unittest.TestCase):
-
     def setUp(self):
         self.coverage_ticket_response = Mock(spec=[])
         self.coverage_ticket_response.response = Mock(spec=["dynamic_field_get"])
@@ -18,7 +17,10 @@ class CoverageTicketTestCase(unittest.TestCase):
                 df_value.value = "foo"
 
             return df_value
-        self.coverage_ticket_response.response.dynamic_field_get.side_effect = dynamic_field_get_side_effect
+
+        self.coverage_ticket_response.response.dynamic_field_get.side_effect = (
+            dynamic_field_get_side_effect
+        )
 
     def test_get_foo(self):
         coverage_ticket = CoverageTicket(self.coverage_ticket_response)
