@@ -25,7 +25,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
                 "vat_number",
                 "phone",
                 "has_active_contracts",
-                "language"
+                "language",
             ]
         )
         self.service_data = Mock(
@@ -63,7 +63,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
                 "mobile_pack_contracts",
                 "all_grouped_SIMS_recieved",
                 "has_grouped_mobile_with_previous_owner",
-                "technology"
+                "technology",
+                "product_ba_mm",
             ]
         )
 
@@ -75,11 +76,13 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["ProcessManagementProcessID"], "FiberProcessID")
+        self.assertEqual(
+            dynamic_fields_dct["ProcessManagementProcessID"], "FiberProcessID"
+        )
 
     def test_previous_phone_field(self):
         self.service_data.previous_contract_phone = "666666666"
@@ -88,13 +91,13 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(
             dynamic_fields_dct["telefonFixAntic"],
-            self.service_data.previous_contract_phone
+            self.service_data.previous_contract_phone,
         )
 
     def test_previous_address_field(self):
@@ -104,13 +107,13 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(
             dynamic_fields_dct["direccioServeiAntic"],
-            self.service_data.previous_contract_address
+            self.service_data.previous_contract_address,
         )
 
     def test_pon_field(self):
@@ -120,13 +123,12 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(
-            dynamic_fields_dct["ponAntic"],
-            self.service_data.previous_contract_pon
+            dynamic_fields_dct["ponAntic"], self.service_data.previous_contract_pon
         )
 
     def test_previous_contract_fiber_speed_field(self):
@@ -136,13 +138,13 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(
             dynamic_fields_dct["velocitatSollicitadaContracteAnteriorCU"],
-            self.service_data.previous_contract_fiber_speed
+            self.service_data.previous_contract_fiber_speed,
         )
 
     def test_activity_id_field(self):
@@ -150,11 +152,13 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["ProcessManagementActivityID"], "FiberActivityID")
+        self.assertEqual(
+            dynamic_fields_dct["ProcessManagementActivityID"], "FiberActivityID"
+        )
 
     # TODO: Are we using this field?????
     def test_contract_id_field(self):
@@ -162,7 +166,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -175,7 +179,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -188,7 +192,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -201,7 +205,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -214,7 +218,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -227,7 +231,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -240,7 +244,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -253,7 +257,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -266,7 +270,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -279,7 +283,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -292,7 +296,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -305,7 +309,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -318,7 +322,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -331,7 +335,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -344,7 +348,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -357,7 +361,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -370,7 +374,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -383,7 +387,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -396,7 +400,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -409,7 +413,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -422,7 +426,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -435,7 +439,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -448,7 +452,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -461,7 +465,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -474,7 +478,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -487,7 +491,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -500,7 +504,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -513,7 +517,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -526,7 +530,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -541,7 +545,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -557,7 +561,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -565,13 +569,13 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertNotIn("nomCognomSociAntic", dynamic_fields_dct.keys())
 
     def test_previous_provider_does_not_exist_when_location_change(self):
-        self.service_data.type = 'location_change'
+        self.service_data.type = "location_change"
 
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -584,7 +588,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -597,7 +601,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -694,3 +698,17 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["flagDocumentacio"], "0")
+
+    def test_product_ba_mm(self):
+        self.service_data.product_ba_mm = "fibra300"
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id,
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(
+            dynamic_fields_dct["productBAMM"], self.service_data.product_ba_mm
+        )
