@@ -3,15 +3,16 @@ import unittest
 from mock import Mock, patch
 
 from otrs_somconnexio.otrs_models.fiber_ticket import FiberTicket
-from otrs_somconnexio.otrs_models.configurations.provision.fiber_ticket import FiberTicketConfiguration
+from otrs_somconnexio.otrs_models.configurations.provision.fiber_ticket import (
+    FiberTicketConfiguration,
+)
 
 
 class FiberTicketTestCase(unittest.TestCase):
-
-    @patch('otrs_somconnexio.otrs_models.provision_ticket.Ticket')
+    @patch("otrs_somconnexio.otrs_models.provision_ticket.Ticket")
     def test_build_ticket(self, MockTicket):
-        customer_data = Mock(spec=['id'])
-        service_data = Mock(spec=['order_id', 'technology'])
+        customer_data = Mock(spec=["id"])
+        service_data = Mock(spec=["order_id", "technology"])
 
         expected_ticket_arguments = {
             "Title": "Ticket#{} - Només fibra".format(service_data.order_id),
@@ -28,11 +29,11 @@ class FiberTicketTestCase(unittest.TestCase):
         FiberTicket(service_data, customer_data)._build_ticket()
         MockTicket.assert_called_with(expected_ticket_arguments)
 
-    @patch('otrs_somconnexio.otrs_models.provision_ticket.Ticket')
+    @patch("otrs_somconnexio.otrs_models.provision_ticket.Ticket")
     def test_build_ticket_mixed(self, MockTicket):
-        customer_data = Mock(spec=['id'])
-        service_data = Mock(spec=['order_id', 'technology'])
-        service_data.technology = 'Mixta'
+        customer_data = Mock(spec=["id"])
+        service_data = Mock(spec=["order_id", "technology"])
+        service_data.technology = "Mixta"
         expected_ticket_arguments = {
             "Title": "Ticket#{} - Fibra mixta".format(service_data.order_id),
             "Type": FiberTicketConfiguration.type,
@@ -48,27 +49,24 @@ class FiberTicketTestCase(unittest.TestCase):
         FiberTicket(service_data, customer_data)._build_ticket()
         MockTicket.assert_called_with(expected_ticket_arguments)
 
-    @patch('otrs_somconnexio.otrs_models.provision_ticket.ProvisionArticle')
+    @patch("otrs_somconnexio.otrs_models.provision_ticket.ProvisionArticle")
     def test_build_article(self, MockInternetArticle):
         customer_data = Mock(spec=[])
-        service_data = Mock(spec=['order_id','notes', 'technology'])
+        service_data = Mock(spec=["order_id", "notes", "technology"])
 
         mock_mobile_article = MockInternetArticle.return_value
 
         FiberTicket(service_data, customer_data)._build_article()
 
         MockInternetArticle.assert_called_with(
-            service_data.technology,
-            service_data.order_id,
-            'fiber',
-            service_data.notes
+            service_data.technology, service_data.order_id, "fiber", service_data.notes
         )
         mock_mobile_article.call.assert_called_once()
 
-    @patch('otrs_somconnexio.otrs_models.fiber_ticket.FiberDynamicFields')
+    @patch("otrs_somconnexio.otrs_models.fiber_ticket.FiberDynamicFields")
     def test_build_dynamic_fields(self, MockFiberDynamicFields):
         customer_data = Mock(spec=[])
-        service_data = Mock(spec=['order_id'])
+        service_data = Mock(spec=["order_id"])
 
         mock_fiber_dynamic_fields = MockFiberDynamicFields.return_value
 
@@ -82,7 +80,7 @@ class FiberTicketTestCase(unittest.TestCase):
         )
         mock_fiber_dynamic_fields.all.assert_called_once()
 
-    @patch('otrs_somconnexio.otrs_models.provision_ticket.OTRSClient')
+    @patch("otrs_somconnexio.otrs_models.provision_ticket.OTRSClient")
     def test_create(self, MockOTRSClient):
         customer_data = Mock(
             spec=[
@@ -131,12 +129,13 @@ class FiberTicketTestCase(unittest.TestCase):
                 "all_grouped_SIMS_recieved",
                 "has_grouped_mobile_with_previous_owner",
                 "technology",
+                "product_ba_mm",
             ]
         )
 
-        mock_otrs_client = Mock(spec=['create_otrs_process_ticket'])
+        mock_otrs_client = Mock(spec=["create_otrs_process_ticket"])
         mock_otrs_client.create_otrs_process_ticket.return_value.id = 123
-        mock_otrs_client.create_otrs_process_ticket.return_value.number = '#123'
+        mock_otrs_client.create_otrs_process_ticket.return_value.number = "#123"
         MockOTRSClient.return_value = mock_otrs_client
 
         ticket = FiberTicket(service_data, customer_data)
@@ -145,7 +144,9 @@ class FiberTicketTestCase(unittest.TestCase):
         mock_otrs_client.create_otrs_process_ticket.assert_called_once()
 
         self.assertEqual(ticket.id, 123)
-        self.assertEqual(ticket.number, '#123')
+        self.assertEqual(ticket.number, "#123")
         self.assertEqual(ticket.otrs_configuration.type, "Petición")
         self.assertEqual(ticket.otrs_configuration.SLA, "No pendent resposta")
-        self.assertEqual(ticket.otrs_configuration.service, "Banda Ancha::Fibra::Provisió Fibra")
+        self.assertEqual(
+            ticket.otrs_configuration.service, "Banda Ancha::Fibra::Provisió Fibra"
+        )
