@@ -5,7 +5,6 @@ from otrs_somconnexio.otrs_models.mobile_data import MobileData
 
 
 class MobileDataTestCase(unittest.TestCase):
-
     def test_init(self):
         mobile_data = MobileData(
             order_id=123,
@@ -16,18 +15,18 @@ class MobileDataTestCase(unittest.TestCase):
             previous_owner_vat="740227654G",
             previous_owner_name="name",
             previous_owner_surname="surname",
-            type='new',
+            type="new",
             sc_icc="123456789",
             icc=None,
             product="product",
             notes="Mobile crm lead line",
             has_sim=True,
-            delivery_street='Les Moreres',
-            delivery_city='Alacant',
-            delivery_zip_code='03140',
-            delivery_state='ES-A',
+            delivery_street="Les Moreres",
+            delivery_city="Alacant",
+            delivery_zip_code="03140",
+            delivery_state="ES-A",
             technology="Mòbil",
-            sim_delivery_tracking_code="325"
+            sim_delivery_tracking_code="325",
         )
 
         self.assertIsInstance(mobile_data, MobileData)
