@@ -18,45 +18,49 @@ def dynamic_fields_to_dct(dynamic_fields):
 
 class MobileDynamicFieldsTestCase(unittest.TestCase):
     def setUp(self):
-        self.customer_data = Mock(spec=[
-            'id',
-            'vat_number',
-            'phone',
-            'name',
-            'first_name',
-            'street',
-            'zip',
-            'city',
-            'subdivision',
-            'has_active_contracts',
-            'language'
-        ])
-        self.mobile_data = Mock(spec=[
-            'order_id',
-            'phone_number',
-            'iban',
-            'email',
-            'sc_icc',
-            'icc',
-            'service_internet_unlimited',
-            'type',
-            'previous_owner_vat',
-            'previous_owner_name',
-            'previous_owner_surname',
-            'previous_provider',
-            'product',
-            'has_sim',
-            'sim_delivery_tracking_code',
-            'type',
-            'delivery_street',
-            'delivery_city',
-            'delivery_zip_code',
-            'delivery_state',
-            'technology',
-            'fiber_linked',
-        ])
-        self.mobile_data.type = 'new'
-
+        self.customer_data = Mock(
+            spec=[
+                "id",
+                "vat_number",
+                "phone",
+                "name",
+                "first_name",
+                "street",
+                "zip",
+                "city",
+                "subdivision",
+                "has_active_contracts",
+                "language",
+            ]
+        )
+        self.mobile_data = Mock(
+            spec=[
+                "order_id",
+                "phone_number",
+                "iban",
+                "email",
+                "sc_icc",
+                "icc",
+                "service_internet_unlimited",
+                "type",
+                "previous_owner_vat",
+                "previous_owner_name",
+                "previous_owner_surname",
+                "previous_provider",
+                "product",
+                "has_sim",
+                "sim_delivery_tracking_code",
+                "type",
+                "delivery_street",
+                "delivery_city",
+                "delivery_zip_code",
+                "delivery_state",
+                "technology",
+                "fiber_linked",
+                "shared_bond_id",
+            ]
+        )
+        self.mobile_data.type = "new"
         self.mobile_otrs_process_id = "MobileProcessID"
         self.mobile_otrs_activity_id = "MobileActivityID"
 
@@ -65,57 +69,61 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["ProcessManagementProcessID"], "MobileProcessID")
+        self.assertEqual(
+            dynamic_fields_dct["ProcessManagementProcessID"], "MobileProcessID"
+        )
 
     def test_activity_id_field(self):
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["ProcessManagementActivityID"], "MobileActivityID")
+        self.assertEqual(
+            dynamic_fields_dct["ProcessManagementActivityID"], "MobileActivityID"
+        )
 
     def test_first_name_field(self):
-        self.customer_data.first_name = 'First Name'
+        self.customer_data.first_name = "First Name"
 
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["nomSoci"], "First Name")
 
     def test_name_field(self):
-        self.customer_data.name = 'Name'
+        self.customer_data.name = "Name"
 
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["cognom1"], "Name")
 
     def test_vat_number_field(self):
-        self.customer_data.vat_number = 'NIFCode'
+        self.customer_data.vat_number = "NIFCode"
 
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -128,7 +136,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -141,7 +149,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -154,85 +162,85 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["idioma"], "ca_ES")
 
     def test_order_id_field(self):
-        self.mobile_data.order_id = '2222'
+        self.mobile_data.order_id = "2222"
 
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["IDpeticio"], "2222")
 
     def test_line_field(self):
-        self.mobile_data.phone_number = '666666666'
+        self.mobile_data.phone_number = "666666666"
 
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["liniaMobil"], "666666666")
 
     def test_icc_sc_field(self):
-        self.mobile_data.sc_icc = '1234'
+        self.mobile_data.sc_icc = "1234"
 
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["ICCSC"], "1234")
 
     def test_icc_donor_field(self):
-        self.mobile_data.icc = '4321'
+        self.mobile_data.icc = "4321"
 
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["ICCdonant"], "4321")
 
     def test_service_type_field_new(self):
-        self.mobile_data.type = 'new'
+        self.mobile_data.type = "new"
 
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["tipusServeiMobil"], "altaNova")
 
     def test_service_type_field_portability(self):
-        self.mobile_data.type = 'portability'
+        self.mobile_data.type = "portability"
 
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -245,7 +253,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -256,14 +264,11 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(
-            dynamic_fields_dct["tipusEnviamentSIM"],
-            "CH_SC_OSO_SIM"
-        )
+        self.assertEqual(dynamic_fields_dct["tipusEnviamentSIM"], "CH_SC_OSO_SIM")
 
     def test_service_does_not_have_sim(self):
         self.mobile_data.has_sim = False
@@ -272,7 +277,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -285,7 +290,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -298,7 +303,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -311,7 +316,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -324,7 +329,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -338,7 +343,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -351,7 +356,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -364,7 +369,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -377,7 +382,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -390,7 +395,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -403,7 +408,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -416,7 +421,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -429,7 +434,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -442,7 +447,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -455,7 +460,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -468,7 +473,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -481,7 +486,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -494,7 +499,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -507,12 +512,24 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["OdooContractRefRelacionat"], "72")
 
+    def test_shared_bond_id(self):
+        self.mobile_data.shared_bond_id = "A72"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id,
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["IDAbonamentCompartit"], "A72")
 
     def test_sim_delivery_tracking_code(self):
         self.mobile_data.sim_delivery_tracking_code = "72"
@@ -521,7 +538,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -532,8 +549,19 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             self.mobile_data,
             self.customer_data,
             self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
+            self.mobile_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["flagDocumentacio"], "0")
\ No newline at end of file
+        self.assertEqual(dynamic_fields_dct["flagDocumentacio"], "0")
+
+    def test_confirm_doc(self):
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id,
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["confirmDoc"], "no")
