@@ -4,19 +4,18 @@ from mock import Mock, patch
 
 from otrs_somconnexio.otrs_models.mobile_ticket import MobilePausedTicket
 from otrs_somconnexio.otrs_models.configurations.provision.mobile_ticket import (
-    MobileTicketConfiguration, MobileTicketPausedConfiguration)
+    MobileTicketConfiguration,
+    MobileTicketPausedConfiguration,
+)
 
 
 class MobileTicketPausedTestCase(unittest.TestCase):
-
-    @patch('otrs_somconnexio.otrs_models.provision_ticket.Ticket')
+    @patch("otrs_somconnexio.otrs_models.provision_ticket.Ticket")
     def test_build_mobile_paused_ticket(self, MockTicket):
-        mobile_data = Mock(spec=[
-            'order_id', 'technology'
-        ])
+        mobile_data = Mock(spec=["order_id", "technology"])
         mobile_data.order_id = 123
 
-        customer_data = Mock(spec=['id'])
+        customer_data = Mock(spec=["id"])
 
         expected_ticket_arguments = {
             "Title": "Ticket#{} - Només mòbil".format(mobile_data.order_id),
