@@ -18,45 +18,49 @@ def dynamic_fields_to_dct(dynamic_fields):
 
 class Router4GDynamicFieldsTestCase(unittest.TestCase):
     def setUp(self):
-        self.customer_data = Mock(spec=[
-            'first_name',
-            'name',
-            'vat_number',
-            'phone',
-            'has_active_contracts',
-            'language'
-        ])
-        self.service_data = Mock(spec=[
-            'order_id',
-            'previous_contract_address',
-            'previous_contract_phone',
-            'iban',
-            'email',
-            'phone_number',
-            'service_address',
-            'service_city',
-            'service_zip',
-            'service_subdivision',
-            'service_subdivision_code',
-            'shipment_address',
-            'shipment_city',
-            'shipment_zip',
-            'shipment_subdivision',
-            'previous_service',
-            'previous_provider',
-            'previous_owner_vat',
-            'previous_owner_name',
-            'previous_owner_surname',
-            'notes',
-            'adsl_coverage',
-            'mm_fiber_coverage',
-            'vdf_fiber_coverage',
-            'orange_fiber_coverage',
-            'type',
-            'product',
-            'previous_internal_provider',
-            'technology',
-        ])
+        self.customer_data = Mock(
+            spec=[
+                "first_name",
+                "name",
+                "vat_number",
+                "phone",
+                "has_active_contracts",
+                "language",
+            ]
+        )
+        self.service_data = Mock(
+            spec=[
+                "order_id",
+                "previous_contract_address",
+                "previous_contract_phone",
+                "iban",
+                "email",
+                "phone_number",
+                "service_address",
+                "service_city",
+                "service_zip",
+                "service_subdivision",
+                "service_subdivision_code",
+                "shipment_address",
+                "shipment_city",
+                "shipment_zip",
+                "shipment_subdivision",
+                "previous_service",
+                "previous_provider",
+                "previous_owner_vat",
+                "previous_owner_name",
+                "previous_owner_surname",
+                "notes",
+                "adsl_coverage",
+                "mm_fiber_coverage",
+                "vdf_fiber_coverage",
+                "orange_fiber_coverage",
+                "type",
+                "product",
+                "previous_internal_provider",
+                "technology",
+            ]
+        )
 
         self.router_4G_otrs_process_id = "Router4GProcessID"
         self.router_4G_otrs_activity_id = "Router4GActivityID"
@@ -66,23 +70,26 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["ProcessManagementProcessID"], "Router4GProcessID")
-
+        self.assertEqual(
+            dynamic_fields_dct["ProcessManagementProcessID"], "Router4GProcessID"
+        )
 
     def test_activity_id_field(self):
         dynamic_fields = Router4GDynamicFields(
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["ProcessManagementActivityID"], "Router4GActivityID")
+        self.assertEqual(
+            dynamic_fields_dct["ProcessManagementActivityID"], "Router4GActivityID"
+        )
 
     def test_previous_phone_field(self):
         self.service_data.previous_contract_phone = "666666666"
@@ -91,13 +98,13 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(
             dynamic_fields_dct["telefonFixAntic"],
-            self.service_data.previous_contract_phone
+            self.service_data.previous_contract_phone,
         )
 
     def test_previous_address_field(self):
@@ -107,13 +114,13 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(
             dynamic_fields_dct["direccioServeiAntic"],
-            self.service_data.previous_contract_address
+            self.service_data.previous_contract_address,
         )
 
     # TODO: Are we using this field?????
@@ -122,7 +129,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -135,7 +142,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -148,7 +155,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -161,7 +168,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -174,7 +181,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -187,7 +194,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -200,7 +207,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -213,7 +220,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -226,7 +233,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -239,7 +246,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -252,7 +259,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -265,7 +272,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -278,7 +285,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -291,7 +298,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -304,7 +311,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -317,7 +324,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -330,7 +337,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -343,7 +350,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -356,7 +363,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -369,7 +376,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -382,7 +389,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -395,7 +402,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -408,7 +415,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -421,7 +428,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -434,7 +441,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -447,7 +454,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -460,7 +467,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -473,7 +480,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -486,7 +493,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -501,7 +508,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -517,7 +524,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -531,7 +538,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -544,7 +551,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -557,7 +564,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
@@ -570,8 +577,8 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             self.service_data,
             self.customer_data,
             self.router_4G_otrs_process_id,
-            self.router_4G_otrs_activity_id
+            self.router_4G_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["TecDelServei"], "4G")
\ No newline at end of file
+        self.assertEqual(dynamic_fields_dct["TecDelServei"], "4G")
