@@ -4,15 +4,15 @@ from mock import Mock, patch
 
 from otrs_somconnexio.otrs_models.vf_provisioning_article import VfProvisioningArticle
 
-class VfProvisioningArticleTestCase(unittest.TestCase):
 
-    @patch('otrs_somconnexio.otrs_models.abstract_article.Article')
+class VfProvisioningArticleTestCase(unittest.TestCase):
+    @patch("otrs_somconnexio.otrs_models.abstract_article.Article")
     def test_call(self, MockArticle):
 
         fake_provisioning_dict = {
-            'opportunity_id': '1-2HNXG6I',
-            'offer': '961447541',
-            'ticket': '1234'
+            "opportunity_id": "1-2HNXG6I",
+            "offer": "961447541",
+            "ticket": "1234",
         }
         expected_article_arguments = {
             "Subject": "Aprovisionament del tiquet de Vodafone 1234",
